EasyStepper class

Inheritance

Constructors

EasyStepper({Key? key, required int activeStep, required List<EasyStep> steps, Set<int>? reachedSteps, int? maxReachedStep, bool enableStepTapping = true, Axis direction = Axis.horizontal, OnStepReached? onStepReached, Color? unreachedStepBackgroundColor, Color? unreachedStepTextColor, Color? unreachedStepIconColor, Color? unreachedStepBorderColor, Color? activeStepTextColor, Color? activeStepIconColor, Color? activeStepBackgroundColor, Color? activeStepBorderColor, Color? finishedStepTextColor, Color? finishedStepBackgroundColor, Color? finishedStepBorderColor, Color? finishedStepIconColor, double stepRadius = 30, bool steppingEnabled = true, bool disableScroll = false, bool showTitle = true, AlignmentGeometry alignment = Alignment.center, bool fitWidth = true, bool showScrollbar = true, EdgeInsetsGeometry? padding, bool titlesAreLargerThanSteps = false, double internalPadding = 8, Curve stepAnimationCurve = Curves.linear, Duration stepAnimationDuration = const Duration(seconds: 1), double borderThickness = 0.8, String? loadingAnimation, StepShape stepShape = StepShape.circle, double? stepBorderRadius, BorderType defaultStepBorderType = BorderType.dotted, BorderType? unreachedStepBorderType, BorderType? activeStepBorderType, BorderType? finishedStepBorderType, List<double> dashPattern = const [3, 1], bool showStepBorder = true, bool showLoadingAnimation = true, TextDirection textDirection = TextDirection.ltr, LineStyle? lineStyle})
const

Properties

activeStep int
The index of currently active step.
final
activeStepBackgroundColor Color?
The color of a step background when it is reached.
final
activeStepBorderColor Color?
The border color of a step when it is reached.
final
activeStepBorderType BorderType?
The type of the step border when it is reached normal, dotted.
final
activeStepIconColor Color?
The color of the step icon when it is reached.
final
activeStepTextColor Color?
The color of a step text and icon when it is reached.
final
alignment AlignmentGeometry
Specifies the alignment of IconStepper widget.
final
borderThickness double
The thickness of the step border.
final
dashPattern List<double>
The Pattern of the border dashes when BorderType set to BorderType.dotted.
final
defaultStepBorderType BorderType
The type of the step border for all states (Unreached, Active & Finished) normal, dotted.
final
direction Axis
Whether to show the steps horizontally or vertically. Note: Ensure horizontal stepper goes inside a column and vertical goes inside a row.
final
disableScroll bool
Whether the scrolling is disabled or not.
final
enableStepTapping bool
Whether to allow tapping a step to move to that step or not.
final
finishedStepBackgroundColor Color?
The color of the step background when it is finished.
final
finishedStepBorderColor Color?
The border color of a step when it is finished.
final
finishedStepBorderType BorderType?
The type of the step border when it is finished normal, dotted.
final
finishedStepIconColor Color?
The color of the step icon when it is finished.
final
finishedStepTextColor Color?
The color of the step text and icon when it is finished.
final
fitWidth bool
Whether the stepper take the full width of the screen or not, this property work when disableScroll = true. default True.
final
hashCode int
The hash code for this object.
no setterinherited
internalPadding double
The amount of padding around every step.
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
lineStyle LineStyle?
final
loadingAnimation String?
The loading animation shows when the step is active. Hence, use lottie json files only by adding its path.
final
maxReachedStep int?
The index of highest reached step
final
onStepReached OnStepReached?
Determines what should happen when a step is reached. This callback provides the index of the step that was reached.
final
padding EdgeInsetsGeometry?
The amount of padding around the stepper.
final
reachedSteps Set<int>?
A set of already reached steps
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showLoadingAnimation bool
Show or hide the loading animation inside Step widget. Defaults to True
final
showScrollbar bool
Show Scrollbar in Web or Desktop. default True.
final
showStepBorder bool
Show or Hide step border.
final
showTitle bool
Whether show step title or not.
final
stepAnimationCurve Curve
The curve of the animation to show when a step is reached.
final
stepAnimationDuration Duration
The duration of the animation effect to show when a step is reached.
final
stepBorderRadius double?
The radius of the step border. Hence, stepBorderRadius ignored if stepShape is Circle.
final
steppingEnabled bool
Whether the stepping is enabled or disabled.
final
stepRadius double
The radius of a step.
final
steps List<EasyStep>
Each Step defines a step icon and title. Hence, total number of icons determines the total number of steps.
final
stepShape StepShape
The shape of the step Circle, Rectangle, Triangle.
final
textDirection TextDirection
Text Direction of the app.
final
titlesAreLargerThanSteps bool
Set this to true if the titles (of at least the first or last step) are wider than the step itself. This will allow the stepper to correctly pad them so that the titles don't get cut off
final
unreachedStepBackgroundColor Color?
The color of the step background when it is not reached.
final
unreachedStepBorderColor Color?
The color of the step border when it is not reached.
final
unreachedStepBorderType BorderType?
The type of the step border when it is not reached normal, dotted.
final
unreachedStepIconColor Color?
The color of the step icon when it is not reached.
final
unreachedStepTextColor Color?
The color of the step text and icon when it is not reached.
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<EasyStepper>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited