fitWidth property
Whether the stepper take the full width of the screen or not, this property work when disableScroll = true. default True.
Implementation
final bool fitWidth;
Whether the stepper take the full width of the screen or not, this property work when disableScroll = true. default True.
final bool fitWidth;