loadingAnimation property
The loading animation shows when the step is active. Hence, use lottie json files only by adding its path.
Implementation
final String? loadingAnimation;
The loading animation shows when the step is active. Hence, use lottie json files only by adding its path.
final String? loadingAnimation;