onStepReached property
Determines what should happen when a step is reached. This callback provides the index of the step that was reached.
Implementation
final OnStepReached? onStepReached;
Determines what should happen when a step is reached. This callback provides the index of the step that was reached.
final OnStepReached? onStepReached;