showLoadingAnimation property
Show or hide the loading animation inside Step widget.
Defaults to True
Implementation
final bool showLoadingAnimation;
Show or hide the loading animation inside Step widget.
Defaults to True
final bool showLoadingAnimation;