stepAnimationDuration property
The duration of the animation effect to show when a step is reached.
Implementation
final Duration stepAnimationDuration;
The duration of the animation effect to show when a step is reached.
final Duration stepAnimationDuration;