unreachedStepBackgroundColor property
The color of the step background when it is not reached.
Implementation
final Color? unreachedStepBackgroundColor;
The color of the step background when it is not reached.
final Color? unreachedStepBackgroundColor;