BaseStep class

Inheritance

Constructors

BaseStep({Key? key, required EasyStep step, required bool isActive, required bool isFinished, required bool isUnreached, required bool isAlreadyReached, required VoidCallback? onStepSelected, required bool showTitle, required double radius, required Color? activeStepBackgroundColor, required Color? finishedBackgroundColor, required Color? unreachedBackgroundColor, required Color? activeStepBorderColor, required Color? finishedBorderColor, required Color? unreachedBorderColor, required Color? activeTextColor, required Color? activeIconColor, required Color? finishedTextColor, required Color? unreachedTextColor, required Color? unreachedIconColor, required Color? finishedIconColor, required String? lottieAnimation, required double? padding, required StepShape stepShape, required double? stepRadius, required double borderThickness, required BorderType borderType, required List<double> dashPattern, required bool showStepBorder, required bool showLoadingAnimation, required TextDirection textDirection, required double lineLength, required bool enabled, required Axis direction, required bool showScrollBar})
const

Properties

activeIconColor Color?
final
activeStepBackgroundColor Color?
final
activeStepBorderColor Color?
final
activeTextColor Color?
final
borderThickness double
final
borderType BorderType
final
dashPattern List<double>
final
direction Axis
final
enabled bool
final
finishedBackgroundColor Color?
final
finishedBorderColor Color?
final
finishedIconColor Color?
final
finishedTextColor Color?
final
hashCode int
The hash code for this object.
no setterinherited
isActive bool
final
isAlreadyReached bool
final
isFinished bool
final
isUnreached bool
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
lineLength double
final
lottieAnimation String?
final
onStepSelected VoidCallback?
final
padding double?
final
radius double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showLoadingAnimation bool
final
showScrollBar bool
final
showStepBorder bool
final
showTitle bool
final
step EasyStep
final
stepRadius double?
final
stepShape StepShape
final
textDirection TextDirection
final
unreachedBackgroundColor Color?
final
unreachedBorderColor Color?
final
unreachedIconColor Color?
final
unreachedTextColor Color?
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited