pages/EasyStepper/src/core/easy_border library

Classes

CircularIntervalList<T>
A circular array of dash offsets and lengths.
DashOffset
Specifies the starting position of a dash array on a path, either as a percentage or absolute value.
EasyBorder

Enums

BorderShape
The different supported BorderTypes

Functions

dashPath(Path source, {required CircularIntervalList<double> dashArray, DashOffset? dashOffset}) Path
Creates a new path that is drawn from the segments of source.

Typedefs

PathBuilder = Path Function(Size)