LineStyle class

Constructors

LineStyle({Key? key, LineType lineType = LineType.dotted, Color? defaultLineColor, Color? unreachedLineColor, Color? activeLineColor, Color? finishedLineColor, double lineLength = 40, double lineWidth = 4, double lineThickness = 1, double lineSpace = 5, LineType? unreachedLineType, Color? progressColor, double? progress})
const

Properties

activeLineColor Color?
The color of the line that branches out from active step.
final
defaultLineColor Color?
The color of the line that separates the steps. If null, Theme.of(context).colorScheme.primary will be used.
final
finishedLineColor Color?
The color of the line that branches out from finished steps.
final
hashCode int
The hash code for this object.
no setterinherited
lineLength double
The length of the line that separates the steps.
final
lineSpace double
The space between individual dot within the line that separates the steps.
final
lineThickness double
The thickness of the line that separates the steps.
final
lineType LineType
The type of the lines normal, dotted.
final
lineWidth double
The Width of the dashes in the line.
final
progress double?
Progress value of the active line. Hence, values range from 0 to 1.
final
progressColor Color?
The color of the progress part of the active line that branches out from current step.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
unreachedLineColor Color?
The color of the line that branches out from unreached steps.
final
unreachedLineType LineType?
The type of the unreached lines normal, dotted. if null lineType will be default for all lines.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited