EasyStep class

Constructors

EasyStep({Icon? icon, Icon? finishIcon, Icon? activeIcon, String? title, String? lineText, Widget? customStep, Widget? customTitle, Widget? customLineWidget, bool topTitle = false, bool enabled = true})
Create a new Step with custom icon and optional title
const

Properties

activeIcon Icon?
The icon displayed in the step, when this step is active. if null the default loading widget displayed.
final
customLineWidget Widget?
Create your own widget appear under the step line, Hence: last step does not have a line, if this property is set lineText will be ignored..
final
customStep Widget?
Create your own Widget for step, if this property is set icon, activeIcon and finishIcon will be ignored..
final
customTitle Widget?
Create your own title widget of the step, if this property is set title will be ignored..
final
enabled bool
enable/disable stepping for this step, Default true.
final
finishIcon Icon?
The icon displayed in the step, when this step is finished. if null the main icon remain displayed.
final
hashCode int
The hash code for this object.
no setterinherited
icon Icon?
The icon displayed in the step, you can change size & color for different status from main stepper.
final
lineText String?
The text appear under the step line, Hence: last step does not have a line
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String?
The title of the step.
final
topTitle bool
Show the title above the step icon. Default false.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited