activeIcon property
The icon displayed in the step, when this step is active. if null the default loading widget displayed.
Implementation
final Icon? activeIcon;
The icon displayed in the step, when this step is active. if null the default loading widget displayed.
final Icon? activeIcon;