customLineWidget property

Widget? customLineWidget
final

Create your own widget appear under the step line, Hence: last step does not have a line, if this property is set lineText will be ignored..

Implementation

final Widget? customLineWidget;