customStep property
Create your own Widget for step, if this property is set icon, activeIcon and finishIcon will be ignored..
Implementation
final Widget? customStep;
Create your own Widget for step, if this property is set icon, activeIcon and finishIcon will be ignored..
final Widget? customStep;