customTitle property
Create your own title widget of the step, if this property is set title will be ignored..
Implementation
final Widget? customTitle;
Create your own title widget of the step, if this property is set title will be ignored..
final Widget? customTitle;