finishIcon property
The icon displayed in the step, when this step is finished. if null the main icon remain displayed.
Implementation
final Icon? finishIcon;
The icon displayed in the step, when this step is finished. if null the main icon remain displayed.
final Icon? finishIcon;