UploadImageView class

Inheritance

Constructors

UploadImageView({Key? key, required String cameraReason, required String photoReason, required double width, required double height, required dynamic callbackImage(List<File> imageList), required int maxlength, double? spacing, double? runSpacing, EdgeInsets? margin, EdgeInsets? padding})

Properties

callbackImage ↔ dynamic Function(List<File> imageList)
getter/setter pair
cameraReason String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
height double
getter/setter pair
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
list ↔ RxList<File>
getter/setter pair
margin EdgeInsets?
组件边距
getter/setter pair
maxlength int
getter/setter pair
padding EdgeInsets?
getter/setter pair
photoReason String
getter/setter pair
runSpacing double?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spacing double?
getter/setter pair
supportedImageExtensions List<String>
getter/setter pair
width double
getter/setter pair

Methods

addImage() → dynamic
build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
clickCamera() → dynamic
clickPhoto() → dynamic
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited