FileListView<T> class

Inheritance

Constructors

FileListView({Key? key, required List<T> list, required String getFileUrl(T item), required String getFileType(T item), required String getFileName(T item), EdgeInsetsGeometry? margin, EdgeInsetsGeometry? padding, BoxDecoration? decoration, BoxDecoration? itemDecoration, EdgeInsetsGeometry? itemMargin, EdgeInsetsGeometry? itemPadding})
const

Properties

decoration BoxDecoration?
组件样式
final
getFileName String Function(T item)
final
getFileType String Function(T item)
final
getFileUrl String Function(T item)
外部决定自定义model的文件url 必填
final
hashCode int
The hash code for this object.
no setterinherited
itemDecoration BoxDecoration?
文件item样式
final
itemMargin EdgeInsetsGeometry?
final
itemPadding EdgeInsetsGeometry?
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
list List<T>
图片数组、T是自定义model 必填
final
margin EdgeInsetsGeometry?
组件外边距
final
padding EdgeInsetsGeometry?
组件内边距
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited