HXUtils class

Constructors

HXUtils()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

containsHtmlTags(String input) bool
decryptAES(String encryptedString, String aesKey, String priKey) Map
extractHrefValues(String input) List<String>
extractInnerTextWithRegex(String htmlString) String
formatDuration({int? startTime, int? endTime, int? second}) String
getImageIcon(String type, {double size = 20}) Widget
getTimeFormat(int timeType, DateTime currentTime) String
handleFormatDecimalValue(dynamic value, {String hint = ""}) String
hexToColor(String? hexString) Color?
hideKeyboard() → dynamic
隐藏键盘
hxFormatDate(int? date, List<String> formats, {String nullStr = "-"}) String
parseUrlInfo(String url) UrlInfoModel?
prettyPrintJson(String jsonStr) String
removeHtmlTagsAndContent(String htmlString) String
showDatePicker(BuildContext context, int timeType, DateTime currentTime, dynamic selectTime(DateTime selectTime)) → dynamic
stirngWithRSA(String str, String priKey) String