PermissionCheckUtils class

Constructors

PermissionCheckUtils()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

camera(String reason) Future<bool>
相机权限
file(String reason) Future<bool>
photos(String reason) Future<bool>
相册权限