BaseTextField class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- BaseTextField
Constructors
- BaseTextField({Key? key, required String text, required dynamic callBackValue(String value), String hintText = "", TextAlign? textAlign, EdgeInsetsGeometry? contentPadding, TextInputType? keyboardType = TextInputType.text, bool isPws = false, bool isShowCounterText = false, TextStyle? textStyle, TextStyle? hintStyle, bool? readOnly = false, int? maxLines = 1, int? maxLength, InputDecoration? inputDecoration, TextSelectionControls? selectionControls})
-
const
Properties
- callBackValue → dynamic Function(String value)
-
返回值
final
- contentPadding → EdgeInsetsGeometry?
-
默认 EdgeInsets.fromLTRB(12, 4, 12, 4)
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hintStyle → TextStyle?
-
提示语 style
final
- hintText → String
-
提示语
final
- inputDecoration → InputDecoration?
-
自定义装饰
final
- isPws → bool
-
是否密码类型
final
- isShowCounterText → bool
-
是否显示计数器
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- keyboardType → TextInputType?
-
输入类型
final
- maxLength → int?
-
最大长度
final
- maxLines → int?
-
最大行
final
- readOnly → bool?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectionControls → TextSelectionControls?
-
文本操作控制器(复制剪切等)
final
- text → String
-
初始值
final
- textAlign → TextAlign?
-
文本对齐
final
- textStyle → TextStyle?
-
输入框 style
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< BaseTextField> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited