BaseToast<T> class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Static Methods
-
cancel()
→ dynamic
-
取消显示
-
show<T>([T? t, Widget? indicator])
→ dynamic
-
显示toast 手动消失
-
showError<T>(T t, {int milliseconds = 2000})
→ dynamic
-
失败提示
-
showInfo<T>(T t, {int milliseconds = 2000})
→ dynamic
-
感叹号提示
-
showSuccess<T>(T t, {int milliseconds = 2000})
→ dynamic
-
成功提示
-
showToast<T>(T t, {int milliseconds = 2000, bool isAutoDismiss = true, bool userInteractions = true, EasyLoadingToastPosition position = EasyLoadingToastPosition.top})
→ dynamic
-
默认显示toast
milliseconds 两秒消失
isAutoDismiss 是否自动消失,当为false时,milliseconds失效,需要手动取消显示
userInteractions 允许用户在加载中交互
position 显示位置 默认上方