ExpandAnimationView class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- ExpandAnimationView
Constructors
- ExpandAnimationView({Key? key, required Widget titleView, required Widget contentView, Widget? iconView, double? axisAlignment, EdgeInsets? margin, bool? isExpand, EdgeInsets? padding, BoxDecoration? decoration, EdgeInsets? titleMargin, EdgeInsets? titlePadding, BoxDecoration? titleDecoration})
Properties
- axisAlignment ↔ double?
-
**
控制尺寸缩放时的对齐方式:
-1.0:从顶部/左侧开始
0.0:中间
1.0:从底部/右侧开始 */
getter/setter pair
- contentView ↔ Widget
-
内容view
getter/setter pair
- decoration ↔ BoxDecoration?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- iconView ↔ Widget?
-
点击动画view
getter/setter pair
- isExpand ↔ bool?
-
getter/setter pair
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- margin ↔ EdgeInsets?
-
装饰
getter/setter pair
- padding ↔ EdgeInsets?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- titleDecoration ↔ BoxDecoration?
-
getter/setter pair
- titleMargin ↔ EdgeInsets?
-
头部装饰
getter/setter pair
- titlePadding ↔ EdgeInsets?
-
getter/setter pair
- titleView ↔ Widget
-
头部view
getter/setter pair
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → _ExpandAnimationViewState -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited