Assets class
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- imagesCameraIcon → const String
- Assets for imagesCameraIcon assets/images/camera_icon.png
- imagesCloseRoundIcon → const String
- Assets for imagesCloseRoundIcon assets/images/close_round_icon.png
- imagesDocIcon → const String
- Assets for imagesDocIcon assets/images/doc_icon.png
- imagesExcelIcon → const String
- Assets for imagesExcelIcon assets/images/excel_icon.png
- imagesHxArrowDownIcon → const String
- Assets for imagesHxArrowDownIcon assets/images/hx_arrow_down_icon.png
- imagesHxArrowUpIcon → const String
- Assets for imagesHxArrowUpIcon assets/images/hx_arrow_up_icon.png
- imagesNoDataIcon → const String
- Assets for imagesNoDataIcon assets/images/noData_icon.png
- imagesPdfIcon → const String
- Assets for imagesPdfIcon assets/images/pdf_icon.png
- imagesTxtIcon → const String
- Assets for imagesTxtIcon assets/images/txt_icon.png