UrlInfoModel class
Constructors
- UrlInfoModel({String? scheme, String? host, int? port, String? path, String? query, Map? queryParameters})
-
UrlInfoModel.fromJson(Map<
String, dynamic> json)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- host ↔ String?
-
getter/setter pair
- path ↔ String?
-
getter/setter pair
- port ↔ int?
-
getter/setter pair
- query ↔ String?
-
getter/setter pair
- queryParameters ↔ Map?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scheme ↔ String?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited